#****************************************************************************
#
#  Module: Activate_secRMMSCCM_to_Syslog.ps1
#
#  Purpose: Send secRMM events from SCCM to Syslog.      
#
#  Copyright (c) 2021 Squadra Technologies 
#   
#****************************************************************************

$jsonFile = ('{0}\Configuration.json' -f $PSScriptRoot);
$json = (Get-Content $jsonFile | Out-String | ConvertFrom-Json);
$SCCMSiteCode = $json.SCCMSiteCode;
$Name = $json.Name;

$VBFile = ('{0}\secRMMSCCM_to_Syslog.vbs' -f $PSScriptRoot);
if ((Test-Path ("$VBFile")) -eq $false) {
	$createVbsFile = ('{0}\CreateVbs.ps1' -f $PSScriptRoot);
	& $createVbsFile; 
}

$Query = "SELECT * FROM __InstanceCreationEvent WITHIN 30 WHERE TargetInstance ISA 'SMS_StatusMessage' AND TargetInstance.Component = 'secRMM'";
$EventNamespace = ('root\sms\site_{0}' -f $SCCMSiteCode);

# https://docs.microsoft.com/en-us/windows/win32/wmisdk/receiving-events-securely#securing-the-permanent-subscription
# $creatorAccount = $env:username;
$creatorAccount = "builtin\Administrators";
$SecurityIdentifier = (New-Object System.Security.Principal.NTAccount($creatorAccount)).Translate([System.Security.Principal.SecurityIdentifier]);
[byte[]]$creatorSID = New-Object -TypeName byte[] -ArgumentList $SecurityIdentifier.BinaryLength;
$SecurityIdentifier.GetBinaryForm($creatorSID,0);

$EventFilterArgs = @{
    Name = $Name
	CreatorSID = $creatorSID
    EventNamespace = $EventNamespace
    Query = $Query
    QueryLanguage = 'WQL'
}

$InstanceArgs1 = @{
    Namespace = 'root\subscription'
    Class = '__EventFilter'
    Arguments = $EventFilterArgs
}

$Filter = Set-WmiInstance @InstanceArgs1

$ScriptFileNameFull = ("{0}\{1}.vbs" -f $PSScriptRoot, $Name);

$EventConsumerArgs = @{
    Name = $Name
	CreatorSID = $creatorSID
    ScriptingEngine = 'VBScript'
    ScriptFileName = $ScriptFileNameFull
}

$InstanceArgs2 = @{
    Namespace = 'root\subscription'
    Class = 'ActiveScriptEventConsumer'
    Arguments = $EventConsumerArgs
}

$Consumer = Set-WmiInstance @InstanceArgs2

$FilterConsumerBingingArgs = @{
	CreatorSID = $creatorSID
    Filter = $Filter
    Consumer = $Consumer
	MaintainSecurityContext = $True
}

$InstanceArgs3 = @{
    Namespace = 'root\subscription'
    Class = '__FilterToConsumerBinding'
    Arguments = $FilterConsumerBingingArgs
}

$Binding = Set-WmiInstance @InstanceArgs3
