$jsonFile = ('{0}\Configuration.json' -f $PSScriptRoot);
$json = (Get-Content $jsonFile | Out-String | ConvertFrom-Json);
$SCCMSiteCode = $json.SCCMSiteCode;
$Name = $json.Name;
$ReturnCode = "0";

if ($null -ne $Name) {
	Write-Host "Checking on WMI $Name for SCCM Site Code $SCCMSiteCode";
	$Filter = Get-WMIObject -Namespace root/Subscription -Class __EventFilter -Filter "name='$Name'";
	$Consumer = Get-WMIObject -Namespace root/Subscription -Class ActiveScriptEventConsumer -Filter "name='$Name'";
	$Binding = Get-WMIObject -Namespace root/Subscription -Class __FilterToConsumerBinding -Filter "__Path LIKE '%$Name%'";

	if ($null -ne $Filter) {
		Write-Host "WMI Filter exists.";
	}
	else {
		Write-Error "WMI Filter does not exist.";
		$ReturnCode = "-1";
	}

	if ($ReturnCode -eq "0") {
		if ($null -ne $Consumer) {
			Write-Host "WMI Consumer exists.";
		}
		else {
			Write-Error "WMI Consumer does not exist.";
			$ReturnCode = "-2";
		}

		if ($ReturnCode -eq "0") {
			if ($null -ne $Binding) {
				Write-Host "WMI Binding exists.";
			}
			else {
				Write-Error "WMI Binding does not exist.";
				$ReturnCode = "-3";
			}	
		}
	}

	# monitor Event Viewer->Applications and Services Logs->Microsoft->Windows->WMI-Activity
	# Event id = 5857
	# ActiveScriptEventConsumer provider started with result code 0x0. HostProcess = wmiprvse.exe; ProcessID = 5052; ProviderPath = %SystemRoot%\system32\wbem\scrcons.exe
	# C:\Windows\system32\wbem\scrcons.exe

}
else {
	Write-Host 'Could not process file Configuration.txt';
	$ReturnCode = "-4";
}

$ReturnCodeFile = ('{0}\ReturnCode.txt' -f $PSScriptRoot);
Set-Content -Value $ReturnCode -Path $ReturnCodeFile -Force
